.. _contributor_testing:
.. _test_your_code:

==============
Testing pylint
==============

Pylint is very well tested and has a high code coverage. New contributions are not accepted
unless they include tests.

.. toctree::
   :maxdepth: 3
   :titlesonly:

   install
   launching_test
   writing_test
